Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ForbiddenResponse ¶
type ForbiddenResponse struct {
Message string `json:"message"`
InvoiceErrors []InvoiceError `json:"invoice_errors"`
}
ForbiddenResponse represents a 403 Forbidden response to a sign transaction request.
type InvoiceError ¶
type InvoiceError struct {
OperationIndex uint32 `json:"operation_index"`
Reason Reason `json:"reason"`
}
InvoiceError is an error specific to an operation (or its corresponding invoice) in the transaction
type Request ¶
type Request struct {
KinVersion int `json:"kin_version"`
// SolanaTransaction is a base64-encoded Solana transaction
SolanaTransaction []byte `json:"solana_transaction"`
// InvoiceList is a base64-encoded protobuf InvoiceList
InvoiceList []byte `json:"invoice_list,omitempty"`
}
Request contains the body of a sign transaction request.
type SuccessResponse ¶
type SuccessResponse struct {
// EnvelopeXDR is a base64-encoded transaction envelope XDR
EnvelopeXDR []byte `json:"envelope_xdr"`
// Signature is a base64-encoded transaction signature.
//
// The endpoint may or may not have provided a signature based on the
// provided transaction.
Signature []byte
}
SuccessResponse represents a 200 OK response to a sign transaction request.
func (*SuccessResponse) GetEnvelopeXDR ¶
func (r *SuccessResponse) GetEnvelopeXDR() (*xdr.TransactionEnvelope, error)
Click to show internal directories.
Click to hide internal directories.